@@ -98,7 +98,7 @@ def test_get_device_attributes_via_ungetch():
         return b'OK'
 
     output = pty_test(child, parent_func=None, test_name='test_get_device_attributes_via_ungetch')
-    assert output == '\x1b[cOK'
+    assert output == '\x1b[c\x1b[6nOK'
 
 
 def test_get_device_attributes_timeout():
@@ -112,7 +112,7 @@ def test_get_device_attributes_timeout():
         return b'TIMEOUT'
 
     output = pty_test(child, parent_func=None, test_name='test_get_device_attributes_timeout')
-    assert output == '\x1b[cTIMEOUT'
+    assert output == '\x1b[c\x1b[6nTIMEOUT'
 
 
 def test_get_device_attributes_force_bypass_cache():
@@ -136,7 +136,7 @@ def test_get_device_attributes_force_bypass_cache():
 
     output = pty_test(child, parent_func=None,
                       test_name='test_get_device_attributes_force_bypass_cache')
-    assert output == '\x1b[c\x1b[cFORCED'
+    assert output == '\x1b[c\x1b[6n\x1b[c\x1b[6nFORCED'
 
 
 def test_get_device_attributes_no_force_uses_cache():
@@ -161,7 +161,7 @@ def test_get_device_attributes_no_force_uses_cache():
 
     output = pty_test(child, parent_func=None,
                       test_name='test_get_device_attributes_no_force_uses_cache')
-    assert output == '\x1b[cNO_FORCE'
+    assert output == '\x1b[c\x1b[6nNO_FORCE'
 
 
 def test_get_device_attributes_retry_after_failure():
@@ -183,7 +183,7 @@ def test_get_device_attributes_retry_after_failure():
 
     output = pty_test(child, parent_func=None,
                       test_name='test_get_device_attributes_retry_after_failure')
-    assert output == '\x1b[c\x1b[cRETRY'
+    assert output == '\x1b[c\x1b[6n\x1b[c\x1b[6nRETRY'
 
 
 def test_get_device_attributes_sticky_failure():
@@ -203,7 +203,7 @@ def test_get_device_attributes_sticky_failure():
 
     output = pty_test(child, parent_func=None,
                       test_name='test_get_device_attributes_sticky_failure')
-    assert output == '\x1b[cSTICKY'
+    assert output == '\x1b[c\x1b[6nSTICKY'
 
 
 def test_get_device_attributes_multiple_extensions():
@@ -223,7 +223,7 @@ def test_get_device_attributes_multiple_extensions():
 
     output = pty_test(child, parent_func=None,
                       test_name='test_get_device_attributes_multiple_extensions')
-    assert output == '\x1b[cMULTI'
+    assert output == '\x1b[c\x1b[6nMULTI'
 
 
 def test_device_attribute_init_with_none_extensions():
@@ -253,18 +253,16 @@ def test_device_attribute_raw_stored():
     assert da.raw == raw
 
 
-def test_get_kitty_keyboard_state_boundary_neither_response():
-    """Test boundary detection when neither Kitty nor DA1 response matches."""
+def test_get_kitty_keyboard_state_boundary_no_response():
+    """Kitty keyboard query sets sticky failure when no response."""
     @as_subprocess
     def child():
         stream = io.StringIO()
         term = TestTerminal(stream=stream, force_styling=True)
         term._is_a_tty = True
 
-        term.ungetch('garbage_response')
         flags = term.get_kitty_keyboard_state(timeout=0.01)
         assert flags is None
-        assert term._kitty_kb_first_query_attempted is True
         assert term._kitty_kb_first_query_failed is True
 
         flags2 = term.get_kitty_keyboard_state(timeout=1.0)
@@ -272,23 +270,18 @@ def test_get_kitty_keyboard_state_boundary_neither_response():
     child()
 
 
-def test_get_kitty_keyboard_state_boundary_da1_only():
-    """Test boundary detection when only DA1 responds."""
+def test_get_kitty_keyboard_state_cpr_fast_negative():
+    """Kitty keyboard query returns None quickly via CPR boundary."""
     @as_subprocess
     def child():
         stream = io.StringIO()
         term = TestTerminal(stream=stream, force_styling=True)
         term._is_a_tty = True
 
-        # DA1 response: VT420 (64) with 132-col (1), Printer (2) - no Kitty protocol
-        term.ungetch('\x1b[?64;1;2c')
-        flags = term.get_kitty_keyboard_state(timeout=0.01)
+        term.ungetch('\x1b[10;20R')
+        flags = term.get_kitty_keyboard_state(timeout=0.5)
         assert flags is None
-        assert term._kitty_kb_first_query_attempted is True
         assert term._kitty_kb_first_query_failed is True
-
-        flags2 = term.get_kitty_keyboard_state(timeout=1.0)
-        assert flags2 is None
     child()
 
 
